<div class="login-form hidden" id="signin-form">
	{% if user.is_authenticated %}
	<p>Usuario logeado</p>
	<p>{{ user.username }}</p>
	{% else %}
	<p>
		Sign In
	</p>
	<form action="" method="post">
		{% csrf_token %}
		<div>
			{{ form_signin.username.errors }}
			<span class="icon-user"></span>
			{{ form_signin.username }}
		</div>
		<div>
			{{ form_signin.password.errors }}
			<span class="icon-lock"></span>
			{{ form_signin.password }}
		</div>

		<input class="form-button" type="submit" value="Sign in">
	</form>
	{% endif %}
</div>