<div class="login-form hidden" id="signup-form">
	<p>
		Sign up
	</p>
	<form action="" method='post'>
		{% csrf_token %}
		<div>
			{{ form_signup.username.errors }}
			<span class="icon-user"></span>
			{{ form_signup.username }}
		</div>
		<div>
			{{ form_signup.email.errors }}
			<span class="icon-mail"></span>
			{{ form_signup.email }}
		</div>
		<div>
			{{ form_signup.password1.errors }}
			<span class="icon-lock"></span>
			{{ form_signup.password1 }}
		</div>
		<div>
			{{ form_signup.password2.errors }}
			<span class="icon-lock"></span>
			{{ form_signup.password2 }}
		</div>
		<input class="form-button" type="submit" value="Sign up">
	</form>
</div>